# Validate an IPv6 address
type Stdlib::IP::Address::V6 = Variant[
  Stdlib::IP::Address::V6::Full,
  Stdlib::IP::Address::V6::Compressed,
  Stdlib::IP::Address::V6::Alternative,
  Stdlib::IP::Address::V6::Nosubnet,
]
