# Validate an IPv6 address without subnet
type Stdlib::IP::Address::V6::Nosubnet = Variant[
  Stdlib::IP::Address::V6::Nosubnet::Full,
  Stdlib::IP::Address::V6::Nosubnet::Compressed,
  Stdlib::IP::Address::V6::Nosubnet::Alternative,
]
